Boost logo

Boost-Commit :

From: john_at_[hidden]
Date: 2008-04-09 11:31:33


Author: johnmaddock
Date: 2008-04-09 11:31:33 EDT (Wed, 09 Apr 2008)
New Revision: 44127
URL: http://svn.boost.org/trac/boost/changeset/44127

Log:
Update for bug report #1790.
Text files modified:
   trunk/libs/config/test/Jamfile.v2 | 2 +-
   trunk/libs/config/test/config_info.cpp | 1 +
   trunk/libs/config/test/config_test.cpp | 2 +-
   trunk/libs/config/test/has_tr1_regex_fail.cpp | 15 +++++++++------
   trunk/libs/config/test/has_tr1_regex_pass.cpp | 17 ++++++++++-------
   5 files changed, 22 insertions(+), 15 deletions(-)

Modified: trunk/libs/config/test/Jamfile.v2
==============================================================================
--- trunk/libs/config/test/Jamfile.v2 (original)
+++ trunk/libs/config/test/Jamfile.v2 2008-04-09 11:31:33 EDT (Wed, 09 Apr 2008)
@@ -1,7 +1,7 @@
 #
 # Regression test Jamfile for boost configuration setup.
 # *** DO NOT EDIT THIS FILE BY HAND ***
-# This file was automatically generated on Wed Apr 09 12:31:02 2008
+# This file was automatically generated on Wed Apr 09 16:30:14 2008
 # by libs/config/tools/generate.cpp
 # Copyright John Maddock.
 # Use, modification and distribution are subject to the

Modified: trunk/libs/config/test/config_info.cpp
==============================================================================
--- trunk/libs/config/test/config_info.cpp (original)
+++ trunk/libs/config/test/config_info.cpp 2008-04-09 11:31:33 EDT (Wed, 09 Apr 2008)
@@ -1023,6 +1023,7 @@
 
 
 
+
    // END GENERATED BLOCK
 
    PRINT_MACRO(BOOST_INTEL);

Modified: trunk/libs/config/test/config_test.cpp
==============================================================================
--- trunk/libs/config/test/config_test.cpp (original)
+++ trunk/libs/config/test/config_test.cpp 2008-04-09 11:31:33 EDT (Wed, 09 Apr 2008)
@@ -1,4 +1,4 @@
-// This file was automatically generated on Wed Apr 09 12:31:02 2008
+// This file was automatically generated on Wed Apr 09 16:30:14 2008
 // by libs/config/tools/generate.cpp
 // Copyright John Maddock 2002-4.
 // Use, modification and distribution are subject to the

Modified: trunk/libs/config/test/has_tr1_regex_fail.cpp
==============================================================================
--- trunk/libs/config/test/has_tr1_regex_fail.cpp (original)
+++ trunk/libs/config/test/has_tr1_regex_fail.cpp 2008-04-09 11:31:33 EDT (Wed, 09 Apr 2008)
@@ -1,15 +1,18 @@
-// This file was automatically generated on Sat Apr 02 11:49:12 2005
+// This file was automatically generated on Wed Apr 09 16:30:13 2008
 // by libs/config/tools/generate.cpp
 // Copyright John Maddock 2002-4.
 // Use, modification and distribution are subject to the
 // Boost Software License, Version 1.0. (See accompanying file
 // LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-// See http://www.boost.org/libs/config for the most recent version.
+// See http://www.boost.org/libs/config for the most recent version.//
+// Revision $Id$
+//
 
-// Test file for macro BOOST_HAS_TR1_ARRAY
+
+// Test file for macro BOOST_HAS_TR1_REGEX
 // This file should not compile, if it does then
// BOOST_HAS_TR1_ARRAY should be defined.
 // See file boost_has_tr1_regex.ipp for details
 
 // Must not have BOOST_ASSERT_CONFIG set; it defeats
@@ -21,7 +24,7 @@
 #include <boost/config.hpp>
 #include "test.hpp"
 
-#ifndef BOOST_HAS_TR1_ARRAY
+#ifndef BOOST_HAS_TR1_REGEX
 #include "boost_has_tr1_regex.ipp"
 #else
 #error "this file should not compile"
@@ -29,6 +32,6 @@
 
 int main( int, char *[] )
 {
- return boost_has_tr1_array::test();
+ return boost_has_tr1_regex::test();
 }
 
@@ -1,15 +1,18 @@
 // This file should not compile, if it does then
-// BOOST_HAS_TR1_ARRAY should be defined.
+// BOOST_HAS_TR1_REGEX should be defined.
 // See file boost_has_tr1_regex.ipp for details
 

Modified: trunk/libs/config/test/has_tr1_regex_pass.cpp
==============================================================================
--- trunk/libs/config/test/has_tr1_regex_pass.cpp (original)
+++ trunk/libs/config/test/has_tr1_regex_pass.cpp 2008-04-09 11:31:33 EDT (Wed, 09 Apr 2008)
@@ -1,15 +1,18 @@
-// This file was automatically generated on Sat Apr 02 11:49:12 2005
+// This file was automatically generated on Wed Apr 09 16:30:13 2008
 // by libs/config/tools/generate.cpp
 // Copyright John Maddock 2002-4.
 // Use, modification and distribution are subject to the
 // Boost Software License, Version 1.0. (See accompanying file
 // LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-// See http://www.boost.org/libs/config for the most recent version.
+// See http://www.boost.org/libs/config for the most recent version.//
+// Revision $Id$
+//
 
-// Test file for macro BOOST_HAS_TR1_ARRAY
+
+// Test file for macro BOOST_HAS_TR1_REGEX
 // This file should compile, if it does not then
// BOOST_HAS_TR1_ARRAY should not be defined.
 // See file boost_has_tr1_regex.ipp for details
 
 // Must not have BOOST_ASSERT_CONFIG set; it defeats
@@ -21,14 +24,14 @@
 #include <boost/config.hpp>
 #include "test.hpp"
 
-#ifdef BOOST_HAS_TR1_ARRAY
+#ifdef BOOST_HAS_TR1_REGEX
 #include "boost_has_tr1_regex.ipp"
 #else
-namespace boost_has_tr1_array = empty_boost;
+namespace boost_has_tr1_regex = empty_boost;
 #endif
 
 int main( int, char *[] )
 {
- return boost_has_tr1_array::test();
+ return boost_has_tr1_regex::test();
 }
 
@@ -1,15 +1,18 @@
 // This file should compile, if it does not then
-// BOOST_HAS_TR1_ARRAY should not be defined.
+// BOOST_HAS_TR1_REGEX should not be defined.
 // See file boost_has_tr1_regex.ipp for details
 


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk